@@ -27,9 +27,11 @@ labels = read.read_post_proc(input_file)[12]
 modes = read.read_post_proc(input_file)[13]
 temperatures_folders = read.read_post_proc(input_file)[14]
 NAC = read.read_post_proc(input_file)[15]
+appendix = read.read_post_proc(input_file)[16]
 
 K = read.read_FC(file_forces)
 BORN_file = 'BORN'
+prefix = ''
 
 
 tot_atoms_uc = int(np.sum(n_atom_unit_cell)) 
@@ -41,22 +43,25 @@ SCell, Ruc, Suc, R0, R0_repeat, S0, masses, masses_uc = read.read_SPOSCAR_and_ma
 if(plot_type==0):
     print('Generating plot 0...')
     namedir = plot.create_folder('')
-    freq = np.loadtxt('ZS', usecols=0)
+    freq = np.loadtxt(prefix+'ZS'+appendix, usecols=0)
     meta = len(freq)
     for i in range(Nqs_path):
         to_skip = (1+meta)*i
-        ZZ = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
+        ZZ = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+1, max_rows=meta)
         Z_q = ZZ[:,0]
         Z = ZZ[:,1:]
         to_skip2 = 4*i
-        Params = np.genfromtxt('quasiparticles',skip_header=to_skip2+1, max_rows=3)
+        Params = np.genfromtxt(prefix+'quasiparticles',skip_header=to_skip2+1, max_rows=3)
         
         k_scaled = ks_scaled_path[i]
         k = ks_path[i]
         
         # harmonic things
         D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
-        eigvals, eigvecs, omegas = util.get_eigvals_eigvec(D)
+        eigvals = np.linalg.eigvalsh(D)
+        idx = np.argsort(eigvals)
+        eigvals = eigvals[idx]
+        omegas = np.sqrt(eigvals)/2/np.pi
 
         freq_disp = omegas
         print(' Creating plots for k point = ', k_scaled)
@@ -65,8 +70,8 @@ if(plot_type==0):
             if(gaussian_smoothing != 0):
                 if(gaussian_smoothing < 0):
                     sig, mi = params[-1]/2, freq[int(len(freq)/2)]
-                else:
-                    sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
+            else:
+                sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
             if(sig==0):
                 sig = 0.0001
 
@@ -79,7 +84,7 @@ if(plot_type==0):
 
 if(plot_type==1):
     print('Generating plot 1...')
-    freq = np.loadtxt('ZS', usecols=0)
+    freq = np.loadtxt('ZS'+appendix, usecols=0)
     meta = len(freq)
     ZQS = [np.zeros(meta)]
     count = 1
@@ -87,12 +92,12 @@ if(plot_type==1):
     accepted_labels = []
     for i in range(Nqs_path):
         to_skip = (1+meta)*i
-        qpoint = np.genfromtxt('Zqs',skip_header=to_skip+0, max_rows=1)
+        qpoint = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+0, max_rows=1)
         for j in range(len(kinput)):
             if(np.allclose(qpoint, kinput[j]) and (qpoint.tolist() not in accepted_qpoints)):
                 accepted_qpoints.append(qpoint.tolist())
                 accepted_labels.append(labels[j])
-                Zq = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)[:,0]
+                Zq = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+1, max_rows=meta)[:,0]
                 
                 sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
                 if(sig<=0):
@@ -111,18 +116,18 @@ if(plot_type==1):
     
 if(plot_type==2): 
     print('Generating plot 2...')
-    freq = np.loadtxt('ZS', usecols=0)
+    freq = np.loadtxt('ZS'+appendix, usecols=0)
     meta = len(freq)
     ZQS = []#np.zeros((meta, tot_atoms_uc*3+1, len(kinput)))
-    # count = 0
+    count = 0
     accepted_qpoints = []
     accepted_labels = []
     freqs_from_disp = np.zeros((tot_atoms_uc*3,len(kinput)))
     for i in range(Nqs_path):
         to_skip = (1+meta)*i
-        qpoint = np.genfromtxt('Zqs',skip_header=to_skip+0, max_rows=1)
+        qpoint = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+0, max_rows=1)
         to_skip2 = 4*i
-        Params = np.genfromtxt('quasiparticles',skip_header=to_skip2+1, max_rows=3)
+        Params = np.genfromtxt(prefix+'quasiparticles'+appendix,skip_header=to_skip2+1, max_rows=3)
         
         for j in range(len(kinput)):
             k_scaled = kinput[j]
@@ -142,14 +147,14 @@ if(plot_type==2):
                         freqs_from_disp[:,count] = omegas
                         break
                 
-                Zq = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
+                Zq = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+1, max_rows=meta)
                 for n in range(tot_atoms_uc*3):
                     params = Params[:,n]
                     if(gaussian_smoothing != 0):
                         if(gaussian_smoothing < 0):
                             sig, mi = params[-1]/2, freq[int(len(freq)/2)]
-                        else:
-                            sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
+                    else:
+                        sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
                     if(sig==0):
                         sig = 0.0001
     
@@ -159,7 +164,7 @@ if(plot_type==2):
                     Zq[:,n+1] = convolution
                 Zq[:,0] = np.sum(Zq[:,1::], axis=1)
                 ZQS.append(Zq[:,:])
-                # count = count + 1
+                count = count + 1
                 
     ZQS = np.array(ZQS)
     plot.plot2(freq,ZQS, modes, accepted_labels, freqs_from_disp)
@@ -179,12 +184,12 @@ if(plot_type==3):
 
         for i in range(Nqs_path):
             to_skip = (4)*i
-            qpoint = np.genfromtxt(temperatures_folders+subdir+'/quasiparticles',skip_header=to_skip+0, max_rows=1)
+            qpoint = np.genfromtxt(temperatures_folders+subdir+prefix+'/quasiparticles'+appendix,skip_header=to_skip+0, max_rows=1)
             for j in range(len(kinput)):
                 if(np.allclose(qpoint, kinput[j]) and (qpoint.tolist() not in accepted_qpoints)):
                     accepted_qpoints.append(qpoint.tolist())
                     accepted_labels.append(labels[j])
-                    omegas_gammas = np.genfromtxt(temperatures_folders+subdir+'/quasiparticles',skip_header=to_skip+1, max_rows=3)
+                    omegas_gammas = np.genfromtxt(temperatures_folders+subdir+prefix+'/quasiparticles'+appendix,skip_header=to_skip+1, max_rows=3)
                     frequencies[:,:,count_q, count_T] = omegas_gammas[0::2,:]
                     count_q = count_q + 1
         count_T = count_T + 1
@@ -276,8 +281,14 @@ if(plot_type==4):
     
 if(plot_type==40):
     print('Generating plot 40...')
-    freq = np.loadtxt('ZS', usecols=0)
+    freq = np.loadtxt('ZS'+appendix, usecols=0)
     meta = len(freq)
+    if(gaussian_smoothing != 0.):
+        if(gaussian_smoothing < 0):
+            print('automatic sigma not allowed in this mode, sigma set to 0.1')
+            sig, mi = 0.1, freq[int(len(freq)/2)]
+    else:
+        sig, mi = 0.001, freq[int(len(freq)/2)]
     
     # take the path the user inputs and find all the k points you can plot
     ks_scal_path_many, ks_path_many, distances = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
@@ -297,7 +308,7 @@ if(plot_type==40):
         # 0K dispersion
         D_0K = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
         eigvals_0K, omegas_0K = util.get_eigvals(D_0K)
-        sigma = gaussian_smoothing
+        sigma = sig # using same sigma for 0K DOS and spectra
         DOS = DOS + np.sum(util.norm_gaussian(freq_DOS,omegas_0K,sigma), axis=1)*weight/(3*tot_atoms_uc*N1N2N3_k*2)
     DOS_info = np.vstack((freq_DOS, DOS)).T
 # =============================================================================
@@ -351,9 +362,9 @@ if(plot_type==40):
         if(np.any(np.all(np.equal(qpoint,ks_scaled_path[i]))) ): # e' un delirio questo ahaha, verifica che il qpoint trovato sia nel kpath
             to_skip = (4)*i
             to_skip_DOS = (1+meta)*i
-            qpoint = np.genfromtxt('quasiparticles',skip_header=to_skip+0, max_rows=1)
+            qpoint = np.genfromtxt(prefix+'quasiparticles'+appendix,skip_header=to_skip+0, max_rows=1)
             accepted_qpoints.append(qpoint.tolist())
-            params = np.genfromtxt('quasiparticles',skip_header=to_skip+1, max_rows=3)
+            params = np.genfromtxt(prefix+'quasiparticles'+appendix,skip_header=to_skip+1, max_rows=3)
             omegas_gammas = params[0::2,:]
             frequencies_MD[:,:,count_comm_k] = omegas_gammas 
             if(np.allclose(qpoint, [0,0,0]) and NAC):
@@ -366,14 +377,7 @@ if(plot_type==40):
 
 # =============================================================================
     # this is for the MD DOS
-    ZQS = np.loadtxt('ZS', usecols=(0,1))
-    if(gaussian_smoothing != 0):
-        if(gaussian_smoothing < 0):
-            print('automatic sigma not allowed in this mode, sigma set to 0.1')
-            sig, mi = 0.1, freq[int(len(freq)/2)]
-        else:
-            sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
-    
+    ZQS = np.loadtxt('ZS'+appendix, usecols=(0,1))
     gaussian = 1/(sig*np.sqrt(2*np.pi)) * np.exp(-.5*((freq-mi)/sig)**2)                
     convolution = signal.fftconvolve(ZQS[:,1],gaussian, mode='same') / sum( gaussian)
     ZQS[:,1] = convolution
@@ -396,7 +400,7 @@ if(plot_type==5):
     num_modes = len(modes)
     K_renorm = np.loadtxt('K_renorm')
 
-    freq = np.loadtxt('ZS', usecols=0)
+    freq = np.loadtxt('ZS'+appendix, usecols=0)
     meta = len(freq)
     
 # =============================================================================        
@@ -443,13 +447,13 @@ if(plot_type==5):
     for i in range(Nqs_path):
         to_skip = (1+meta)*i
         to_skip2 = 4*i
-        Params = np.genfromtxt('quasiparticles',skip_header=to_skip2+1, max_rows=3)
-        qpoint = np.genfromtxt('Zqs',skip_header=to_skip+0, max_rows=1)
+        Params = np.genfromtxt(prefix+'quasiparticles'+appendix,skip_header=to_skip2+1, max_rows=3)
+        qpoint = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+0, max_rows=1)
         for j in range(len(ks_scaled_path)):
             if(np.allclose(qpoint, ks_scaled_path[j]) and ((qpoint.tolist() not in accepted_qpoints) or i==j)): #è un completo delirio
                 accepted_qpoints.append(qpoint.tolist())
                 
-                Zq = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
+                Zq = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+1, max_rows=meta)
                 ZQS[:,count] = Zq[:,0]
                 for b in range(tot_atoms_uc*3):
                     params = Params[:,b]
@@ -474,6 +478,10 @@ if(plot_type==5):
     #this is to reshape spectra according to real branches
     indexes, freqs_reshaped = util.get_real_branches(frequencies, EIGVECS, masses_uc, ks_path_many)
     indexes_0K, freqs_disp_reshaped = util.get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, ks_path_many)
+    
+    # #this is to reshape spectra according to real branches
+    # indexes, freqs_disp_reshaped = util.aaa_get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, Hk, ks_scal_path_many)
+    
     frequencies_reshaped, frequencies_disp_reshaped  = np.copy(frequencies), np.copy(frequencies_disp)
     frequencies_reshaped, frequencies_disp_reshaped = freqs_reshaped, freqs_disp_reshaped
     
@@ -487,6 +495,11 @@ if(plot_type==5):
     else:
         ZQS_proj_interp = ZQS_proj_reshaped[:,range(len(modes)),:]
         
+    # if (interp>0):
+    #     ZQS_proj_interp = util.aaa_interpol_spectrum(ks_path, freq, freqs_from_spectrum, EIGVECS_0K, modes, ZQS_proj_reshaped, interp)
+    # else:
+    #     ZQS_proj_interp = ZQS_proj_reshaped[:,range(len(modes)),:]
+        
     plot.plot_k2(distances_comm, distances_many, frequencies_disp_reshaped, frequencies_reshaped, freq,ZQS,ZQS_proj_interp, x_labels,max_Z,modes)
 
 
@@ -495,7 +508,7 @@ if(plot_type==6):
     # ks_scal_path_many, ks_path_many, distances_many = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
     K_renorm = np.loadtxt('K_renorm')
     
-    freq = np.loadtxt('ZS', usecols=0)
+    freq = np.loadtxt('ZS'+appendix, usecols=0)
     meta = len(freq)
     accepted_qpoints = []
     
@@ -520,7 +533,7 @@ if(plot_type==6):
         eigvals_renorm, eigvecs_renorm, omegas_renorm = util.get_eigvals_eigvec(D_renorm)
         
         to_skip = (1+meta)*i
-        Zq = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
+        Zq = np.genfromtxt(prefix+'Zqs'+appendix,skip_header=to_skip+1, max_rows=meta)
         for b in range(len(modes)):
             mm = modes[b]
             ani = plot.plot6(freq,Zq[:,mm+1],Zq[:,0], k,eigvecs_0K[:,mm],omegas_0K[mm],mm,Ruc,masses_uc, max_Z, title='0K eigenvectors')
@@ -573,10 +586,10 @@ if(plot_type==7):
 
             
         to_skip = (4)*i
-        qpoint = np.genfromtxt('quasiparticles',skip_header=to_skip+0, max_rows=1)
+        qpoint = np.genfromtxt(prefix+'quasiparticles'+appendix,skip_header=to_skip+0, max_rows=1)
         if(direc_sc.tolist() in dirs_C11 and (np.allclose(qpoint_sc_prev,[0,0,0]) or np.allclose(ks_path[i+1],[0,0,0]))):
             
-            params = np.genfromtxt('quasiparticles',skip_header=to_skip+1, max_rows=3)
+            params = np.genfromtxt(prefix+'quasiparticles'+appendix,skip_header=to_skip+1, max_rows=3)
             omegas  = params[0,:]
             
             csi = np.linalg.norm(np.dot(Hk,qpoint))
@@ -630,7 +643,7 @@ if(plot_type==7):
             
             
         if(direc_sc.tolist() in dirs_C12_C44 and np.allclose(qpoint_sc_prev,[0,0,0]) or np.allclose(ks_path[i+1],[0,0,0])):
-            params = np.genfromtxt('quasiparticles',skip_header=to_skip+1, max_rows=3)
+            params = np.genfromtxt(prefix+'quasiparticles'+appendix,skip_header=to_skip+1, max_rows=3)
             omegas  = params[0,:]
             
             #check that k = [csi, csi, 0]
